# $Id: rss.rb,v 1.4 2005/09/06 06:08:29 fdiary Exp $
# Copyright (C) 2003-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
# Copyright (C) 2005 Kazuhiko <kazuhiko@fdiary.net>

def label_rss_recent
  ''
end

def label_rss_config; 'RSS κ'; end
def label_rss_mode_title; 'RSS Υեޥå'; end
def label_rss_mode_candidate
  [ 'unified diff ',
    'word diff  ()',
    'word diff  (ʸ)',
    'HTML  (ʸ)',
  ]
end
def label_rss_menu_title; 'RSS ˥塼ɽ'; end
def label_rss_menu_candidate
  [ '', 'ʤ' ]
end
